--[[
************************************************************************
Project				: SKG
Author				: zhinjio
Project Revision	: oops-alpha
Project Date		: 20090521032914

File				: SKG_GUI_Options.lua
Commit Author		: zhinjio
Commit Revision		: 118
Commit Date			: 20081030164922
************************************************************************
Description	:
	This file contained the definition of the options frame for setting
	the various selectable checkboxes and whatnot.

TODO		:

************************************************************************
(see bottom of file for changelog)
************************************************************************
--]]
local SKG = LibStub( "AceAddon-3.0"):GetAddon( "SKG" )
local SKGL = LibStub( "AceLocale-3.0"):GetLocale( "SKG" )

function SKG_OF_RaidOnlyToggle()
	local db = SKG.db.profile.Options.General
	local ActiveList = SKG_ActiveListTitle:GetText()
	if ( db.raidonly ) then
		SKG_OF_RaidOnlyCB:SetChecked( false )
		SKG_OF_ShowAllCB:SetChecked( true )
		db.raidonly = false

		if ( ( ActiveList ~= nil ) and
			 ( ActiveList ~= "Players" ) ) then
			-- Reserve will "re-enable" if they select a reserved player
			SKG_LF_ReservePlayerButton:Enable()
			SKG_LF_MoveDownButton:Enable()
			SKG_LF_MoveUpButton:Enable()
		end
	else
		SKG_OF_RaidOnlyCB:SetChecked( true )
		SKG_OF_ShowAllCB:SetChecked( false )
		db.raidonly = true

		if ( ( SKG.inRaid ) and
			 ( ActiveList ~= nil ) and
			 ( ActiveList ~= "Players" ) ) then
			-- Reserve will "re-enable" if they select a reserved player
			SKG_LF_ReservePlayerButton:Disable()
			SKG_LF_MoveDownButton:Disable()
			SKG_LF_MoveUpButton:Disable()
		end
	end
	SKG_UpdateCurrentList()
	Dewdrop:Close()
--	SKG:UpdateFuBarTooltip()
end

function SKG_OF_ShowClassColorsClicked()
	local db = SKG.db.profile.Options.General
	if ( db.classColors ) then
		SKG_OF_ShowClassColorsCB:SetChecked( false )
		db.classColors = false
	else
		SKG_OF_ShowClassColorsCB:SetChecked( true )
		db.classColors = true
	end
	SKG_UpdateCurrentList()
	Dewdrop:Close()

--	SKG:UpdateFuBarTooltip()
end

function SKG_OF_AutoOpenClicked()
	local db = SKG.db.profile.Options.General
	if ( db.autoopen ) then
		SKG_OF_AutoOpenCB:SetChecked( false )
		db.autoopen = false
	else
		SKG_OF_AutoOpenCB:SetChecked( true )
		db.autoopen = true
	end
	Dewdrop:Close()

--	SKG:UpdateFuBarTooltip()
end

function SKG_OF_DebugClicked()
	local db = SKG.db.profile.Options.General
	if ( db.debug ) then
		SKG_OF_DebugCB:SetChecked( false )
		db.debug = false
		SKG_DEBUG = false
	else
		SKG_OF_DebugCB:SetChecked( true )
		db.debug = true
		SKG_DEBUG = true
	end
	Dewdrop:Close()

--	SKG:UpdateFuBarTooltip()
end

-- options tables for menus...

SKG.ButtonTextureOptions = {
	type = "group", args = {
		buttonTexture = {
			type = "range", name = "Select texture", desc = "Select texture",
			min = 1, max = 7, step = 1,
			get = function() return SKG.db.profile.Options.General.buttonTexture end,
			set = function( value )
				SKG_SetOptionSwitcherButtonTexture( value )
				SKG.db.profile.Options.General.buttonTexture = value
			end,
		}
	}
}

function SKG_OF_ProfileClicked()
	local profile = SKG.db:GetCurrentProfile()
	if ( profile == "Default" ) then
		-- We're currently in "Default" mode and he wants to switch to character based
		SKG.db:SetProfile( "char" )
		SKG_InitAllPanels()
	else
		-- We're currently in per character mode, and we need to switch back to Default
		SKG.db:SetProfile( "Default" )
		SKG_InitAllPanels()
	end
end

function SKG_OF_ProfileCopyClicked()
	SKG.db:CopyProfile( "Default" )
	SKG_InitAllPanels()
end

-- Options Frame Creation

SKG_OptionsFrame = CreateFrame( "Frame", "SKG_OptionsFrame", SKG_Frame )
	SKG_OptionsFrame:SetClampedToScreen( true )
	SKG_OptionsFrame:SetHeight( 371 )
	SKG_OptionsFrame:SetWidth( 265 )
	SKG_OptionsFrame:SetPoint( "TOPLEFT", SKG_Frame, "TOPRIGHT", -5, -50 )
	SKG_OptionsFrame:EnableMouse( true )
	SKG_OptionsFrame:SetMovable( true )
	SKG_OptionsFrame:SetFrameLevel( 1 )
	SKG_OptionsFrame:SetFrameStrata( "BACKGROUND" )
	SKG_OptionsFrame:SetHitRectInsets( 5, 5, 5, 5 )
	SKG_OptionsFrame:Hide()

	local SKG_OF_Texture = SKG_OptionsFrame:CreateTexture( "SKG_OF_Texture", "ARTWORK" )
		SKG_OF_Texture:SetTexture( [[Interface\Addons\SKG\BLP\OptionsFrame_Texture]] )
		SKG_OF_Texture:SetAllPoints( SKG_OptionsFrame )
		SKG_OF_Texture:SetTexCoord( (( 512 - 265 ) / 512 ), 1, 0, ( 371 / 512 ) )

	local SKG_OF_TitleText = SKG_OptionsFrame:CreateFontString( "SKG_OF_TitleText", "OVERLAY", "GameFontHighlight" )
		SKG_OF_TitleText:SetText( SKGL["SKG_LBL_OF_TITLE_TEXT"] )
		SKG_OF_TitleText:SetPoint( "TOP", SKG_OptionsFrame, "TOP", 0, -3 )
		SKG_OF_TitleText:SetJustifyH( "CENTER" )
		SKG_OF_TitleText:SetHeight( 14 )
		SKG_OF_TitleText:SetWidth( 200 )

	local SKG_OF_ListBehaviorText = SKG_OptionsFrame:CreateFontString( "SKG_OF_ListBehaviorText", "OVERLAY", "GameFontHighlight" )
		SKG_OF_ListBehaviorText:SetText( SKGL["SKG_LBL_OF_LISTBEHAVIOR_TEXT"] )
		SKG_OF_ListBehaviorText:SetPoint( "TOPLEFT", SKG_OptionsFrame, "TOPLEFT", 15, -65 )
		SKG_OF_ListBehaviorText:SetJustifyH( "LEFT" );
		SKG_OF_ListBehaviorText:SetHeight( 14 )
		SKG_OF_ListBehaviorText:SetWidth( 200 )

	local SKG_OF_RaidOnlyCB = CreateFrame( "CheckButton", "SKG_OF_RaidOnlyCB", SKG_OptionsFrame, "UICheckButtonTemplate" )
		SKG_OF_RaidOnlyCB:SetHeight( 24 )
		SKG_OF_RaidOnlyCB:SetWidth( 24 )
		SKG_OF_RaidOnlyCB:SetPoint( "TOPLEFT", SKG_OF_ListBehaviorText, "BOTTOMLEFT", 10, 0 )
		SKG_OF_RaidOnlyCBText:SetText( SKGL["SKG_LBL_OF_RAIDONLYCB_TEXT"] )

		SKG_OF_RaidOnlyCB:SetScript( "OnClick", SKG_OF_RaidOnlyToggle )

		SKG_TooltipDisplay( SKG_OF_RaidOnlyCB, "SKG_OF_RAIDONLYCB_TT", 1 )

	local SKG_OF_ShowAllCB = CreateFrame( "CheckButton", "SKG_OF_ShowAllCB", SKG_OptionsFrame, "UICheckButtonTemplate" )
		SKG_OF_ShowAllCB:SetHeight( 24 )
		SKG_OF_ShowAllCB:SetWidth( 24 )
		SKG_OF_ShowAllCB:SetPoint( "TOPLEFT", SKG_OF_RaidOnlyCB, "BOTTOMLEFT", 0, 5 )
		SKG_OF_ShowAllCBText:SetText( SKGL["SKG_LBL_OF_SHOWALLCB_TEXT"] )

		SKG_OF_ShowAllCB:SetScript( "OnClick", SKG_OF_RaidOnlyToggle )

		SKG_TooltipDisplay( SKG_OF_ShowAllCB, "SKG_OF_SHOWALLCB_TT", 1 )

	local SKG_OF_ShowClassColorsCB = CreateFrame( "CheckButton", "SKG_OF_ShowClassColorsCB", SKG_OptionsFrame, "UICheckButtonTemplate" )
		SKG_OF_ShowClassColorsCB:SetHeight( 24 )
		SKG_OF_ShowClassColorsCB:SetWidth( 24 )
		SKG_OF_ShowClassColorsCB:SetPoint( "TOPLEFT", SKG_OF_ShowAllCB, "BOTTOMLEFT", 0, 5 )
		SKG_OF_ShowClassColorsCBText:SetText( SKGL["SKG_LBL_OF_SHOWCLASSCOLORSCB_TEXT"] )

		SKG_OF_ShowClassColorsCB:SetScript( "OnClick", SKG_OF_ShowClassColorsClicked )

		SKG_TooltipDisplay( SKG_OF_ShowClassColorsCB, "SKG_OF_SHOWCLASSCOLORSCB_TT", 1 )

	local SKG_OF_TextureChooser = SKG_CreateButton(
		"SKG_OF_TextureChooser", SKG_OptionsFrame, 20, 170,
		"TOPLEFT", SKG_OF_ListBehaviorText, "TOPLEFT", 0, -85,
		"GameFontNormalSmall", "GameFontHighlightSmall",
		SKGL["SKG_LBL_OF_CHOOSER_TEXT"],"CENTER", "SKG_OF_CHOOSER_TT" )

		SKG_OF_TextureChooser:SetScript( "OnClick",
			function()
				Dewdrop:Register( this,
					'children', SKG.ButtonTextureOptions,
					'dontHook', true,
					'point', "TOPLEFT",
					'relativePoint', "BOTTOMLEFT"
				)
				this:SetScript( "OnClick",
					function()
						if Dewdrop:IsOpen( this ) then
							Dewdrop:Close()
						else
							Dewdrop:Open( this )
						end
					end
				)
				this:GetScript( "OnClick" )()
			end
		)

	local SKG_OF_ProfileText = SKG_OptionsFrame:CreateFontString( "SKG_OF_ProfileText", "OVERLAY", "GameFontHighlight" )
		SKG_OF_ProfileText:SetText( SKGL["SKG_LBL_OF_PROFILE_TEXT"] )
		SKG_OF_ProfileText:SetPoint( "TOPLEFT", SKG_OF_TextureChooser, "BOTTOMLEFT", 0, -10 )
		SKG_OF_ProfileText:SetJustifyH( "LEFT" );
		SKG_OF_ProfileText:SetHeight( 14 )
		SKG_OF_ProfileText:SetWidth( 200 )

	local SKG_OF_ProfileCB = CreateFrame( "CheckButton", "SKG_OF_ProfileCB", SKG_OptionsFrame, "UICheckButtonTemplate" )
		SKG_OF_ProfileCB:SetHeight( 24 )
		SKG_OF_ProfileCB:SetWidth( 24 )
		SKG_OF_ProfileCB:SetPoint( "TOPLEFT", SKG_OF_ProfileText, "BOTTOMLEFT", 10, 0 )
		SKG_OF_ProfileCBText:SetText( SKGL["SKG_LBL_OF_PROFILECB_TEXT"] )

		SKG_OF_ProfileCB:SetScript( "OnClick", SKG_OF_ProfileClicked )

		SKG_TooltipDisplay( SKG_OF_ProfileCB, "SKG_OF_PROFILECB_TT", 1 )

	local SKG_OF_ProfileCopy = SKG_CreateButton(
		"SKG_OF_ProfileCopy", SKG_OptionsFrame, 20, 170,
		"TOPLEFT", SKG_OF_ProfileCB, "BOTTOMLEFT", 0, -1,
		"GameFontNormalSmall", "GameFontHighlightSmall",
		SKGL["SKG_LBL_OF_PROFCOPY_TEXT"],"CENTER", "SKG_OF_PROFCOPY_TT" )

		SKG_OF_ProfileCopy:SetScript( "OnClick", SKG_OF_ProfileCopyClicked )

	local SKG_OF_MiscText = SKG_OptionsFrame:CreateFontString( "SKG_OF_MiscText", "OVERLAY", "GameFontHighlight" )
		SKG_OF_MiscText:SetText( SKGL["SKG_LBL_OF_MISC_TEXT"] )
		SKG_OF_MiscText:SetPoint( "TOPLEFT", SKG_OF_ProfileCopy, "BOTTOMLEFT", -10, -10 )
		SKG_OF_MiscText:SetJustifyH( "LEFT" );
		SKG_OF_MiscText:SetHeight( 14 )
		SKG_OF_MiscText:SetWidth( 200 )

	local SKG_OF_AutoOpenCB = CreateFrame( "CheckButton", "SKG_OF_AutoOpenCB", SKG_OptionsFrame, "UICheckButtonTemplate" )
		SKG_OF_AutoOpenCB:SetHeight( 24 )
		SKG_OF_AutoOpenCB:SetWidth( 24 )
		SKG_OF_AutoOpenCB:SetPoint( "TOPLEFT", SKG_OF_MiscText, "BOTTOMLEFT", 10, 0 )
		SKG_OF_AutoOpenCBText:SetText( SKGL["SKG_LBL_OF_AUTOOPENCB_TEXT"] )

		SKG_OF_AutoOpenCB:SetScript( "OnClick", SKG_OF_AutoOpenClicked )

		SKG_TooltipDisplay( SKG_OF_AutoOpenCB, "SKG_OF_AUTOOPENCB_TT", 1 )

	local SKG_OF_DebugCB = CreateFrame( "CheckButton", "SKG_OF_DebugCB", SKG_OptionsFrame, "UICheckButtonTemplate" )
		SKG_OF_DebugCB:SetHeight( 24 )
		SKG_OF_DebugCB:SetWidth( 24 )
		SKG_OF_DebugCB:SetPoint( "TOPLEFT", SKG_OF_AutoOpenCB, "BOTTOMLEFT", 0, 5 )
		SKG_OF_DebugCBText:SetText( SKGL["SKG_LBL_OF_DEBUGCB_TEXT"] )

		SKG_OF_DebugCB:SetScript( "OnClick", SKG_OF_DebugClicked )

		SKG_TooltipDisplay( SKG_OF_DebugCB, "SKG_OF_DEBUGCB_TT", 1 )

-- OnLoad stuff here


--[[
************************************************************************
CHANGELOG:

Date : 10/25/08
	Initial attempt with Ace3 instead of LibRock. Added header/footer.
************************************************************************
]]--